"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnalyzeCommand = void 0;
const types_1 = require("../types");
const llm_1 = require("../llm");
const child_process_1 = require("child_process");
class AnalyzeCommand extends types_1.Command {
    async execute(command) {
        try {
            const childProcess = (0, child_process_1.spawn)(command, [], { shell: true });
            childProcess.stdout.on('data', (stdout) => {
                process.stdout.write(stdout);
            });
            childProcess.stderr.on('data', async (stderr) => {
                const errorOutput = stderr.toString();
                process.stderr.write(stderr);
                await llm_1.LLMAnalyse.analyse({
                    errorOutput,
                    command,
                    config: this.config,
                    handleLLMNewToken: (token) => {
                        process.stderr.write(token);
                    },
                    handleLLMStart: () => {
                        process.stderr.write('\n\n**AI Suggestion**\n\n');
                    },
                    handleLLMEnd: () => {
                        process.stderr.write('\n\n**End AI Suggestion**\n\n');
                    },
                });
            });
        }
        catch (e) {
            console.log(e);
        }
    }
}
exports.AnalyzeCommand = AnalyzeCommand;
